# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

try:
    from ._models_py3 import SendMessageRequest
    from ._models_py3 import SmsRecipient
    from ._models_py3 import SmsSendOptions
    from ._models_py3 import SmsSendResponse
    from ._models_py3 import SmsSendResponseItem
except (SyntaxError, ImportError):
    from ._models import SendMessageRequest  # type: ignore
    from ._models import SmsRecipient  # type: ignore
    from ._models import SmsSendOptions  # type: ignore
    from ._models import SmsSendResponse  # type: ignore
    from ._models import SmsSendResponseItem  # type: ignore

from ._azure_communication_sms_service_enums import (
    SmsSendResponseItemRepeatabilityResult,
)

__all__ = [
    'SendMessageRequest',
    'SmsRecipient',
    'SmsSendOptions',
    'SmsSendResponse',
    'SmsSendResponseItem',
    'SmsSendResponseItemRepeatabilityResult',
]
